# DescKGC
[![lint](https://github.com/guangchen811/ComplexKG/actions/workflows/lint.yml/badge.svg)](https://github.com/guangchen811/ComplexKG/blob/main/.github/workflows/lint.yml)
[![unit test](https://github.com/guangchen811/ComplexKG/actions/workflows/test.yml/badge.svg)](https://github.com/guangchen811/ComplexKG/blob/main/.github/workflows/test.yml)
[![PyPI Version](https://img.shields.io/pypi/v/desckgc)](https://pypi.org/project/desckgc/)

This is a package for Knowledge Graph Construction. The official document can be found [here](https://guangchen811.github.io/DescKGC/).
